@@ -16,10 +16,10 @@ _parameter_annotation_schema = {
                     "description": {"type": "string"},
                     "annotation": {"type": "string"},
                     "devices": {
-                        "$ref": "#/definitions/custom_types",
+                        "$ref": "#/definitions/custom_types_plans_devices",
                     },
                     "plans": {
-                        "$ref": "#/definitions/custom_types",
+                        "$ref": "#/definitions/custom_types_plans_devices",
                     },
                     "enums": {
                         "$ref": "#/definitions/custom_types",
@@ -28,6 +28,8 @@ _parameter_annotation_schema = {
                     "min": {"type": "number"},
                     "max": {"type": "number"},
                     "step": {"type": "number"},
+                    "convert_plan_names": {"type": "boolean"},
+                    "convert_device_names": {"type": "boolean"},
                 },
             },
         },
@@ -36,9 +38,26 @@ _parameter_annotation_schema = {
     "definitions": {
         "custom_types": {
             "type": "object",
-            "additionalProperties": {
-                "type": "array",
-                "items": {"type": "string"},
+            "additionalProperties": False,
+            "patternProperties": {
+                "^[_a-zA-Z][_a-zA-Z0-9]*$": {
+                    "type": "array",
+                    "items": {"type": "string"},
+                },
+            },
+        },
+        "custom_types_plans_devices": {
+            "type": "object",
+            "additionalProperties": False,
+            "patternProperties": {
+                "^[_a-zA-Z][_a-zA-Z0-9]*$": {
+                    "anyOf": [
+                        {
+                            "type": "array",
+                            "items": {"type": "string"},
+                        },
+                    ],
+                },
             },
         },
     },
@@ -117,6 +136,7 @@ def parameter_annotation_decorator(annotation):
                     # This parameter will probably have type hint 'some_name: str`.
                     "description": "String selected from a list of strings (similar to enum)",
                     "annotation": "Names",
+
                     # Note, that "devices", "plans" and "names" are treated identically
                     #   during type checking, since they represent lists of strings.
                     #   One parameter may have name groups from "devices", "plans"
@@ -128,31 +148,54 @@ def parameter_annotation_decorator(annotation):
                     },
                 }
 
-                # Parameter that accepts a plan or a list of plans
-                #   (plans must exist in RE Worker namespace,
-                #    reference to the plans will be passed to the plan).
-                "plans_to_run": {
-                    # Text descriptions of parameters are optional.
-                    "description": "Parameter that accepts a plan or a list of plans.",
-                    "annotation": "typing.Union[Plan1, typing.List[Plan2]]",
-                    "plans": {
-                        # Here we have two groups of plans. Names of the plans are used
-                        #   as types in 'annotation'. The example of annotation above
-                        #   allows to pass one plan from the group 'Plan1' or a list of
-                        #   plans from 'Plan2'.
-                        "Plan1": ("count", "scan", "gridscan"),
-                        "Plan2": ("more", "plan", "names"),
-                    },
-                },
-
                 "devices": {
                     "description": "Parameter that accepts the list of devices.",
-                    "annotation": "typing.List[DeviceType1]",
+                    "annotation": "typing.List[typing.Union[DeviceType1, DeviceType2]]",
+
                     # Here we provide the list of devices. 'devices' and 'plans' are
-                    #   treated similarly, but it may be useful to distinguish lists of
-                    #    plans and devices on the stage of plan parameter validation.
+                    #    treated similarly, but should be separated into different sections
+                    #    to implement proper parameter validation. The devices may be listed
+                    #    explicitly by name or using patterns based on regular expressions.
+                    #    The list may contain any combination of names and patterns.
+                    #    The patterns are distinguished from names by leading ``:`` at the
+                    #    beginning of each pattern. Patterns may contain multiple regular
+                    #    expressions separated with ``:``: the first expression is applied
+                    #    to the device name, the second expression to subdevices of the
+                    #    device, the third - to subdevices of subdevices etc. For example,
+                    #    the pattern ``:^stage_:^det:val$ would match the devices with names
+                    #    such as ``stage_sim.det2.val``.
+                    #
+                    #    Adding ``-`` before an expression (after ``:``) excludes the matching
+                    #    devices/subdevices from the list (e.g. ``:^stage_:-^det:val$ adds
+                    #    ``stage_sim`` and ``stage_sim.det2.val`` to the list, but not
+                    #    ``stage_sim.det2``).
+                    #
+                    #    A regular expression may be applied to the full name (including
+                    #    subdevice names) or remaining name of the device. An expression
+                    #    could be labelled as 'full-name' by placing ``?`` before it.
+                    #    For example ``:?^stage_.*val$`` would pick all devices with names
+                    #    starting with ``stage_`` and ending with ``val`` from the complete
+                    #    tree of existing devices. The search depth may be restricted by
+                    #    adding ``depth`` parameter (e.g. ``:?^stage_.*val$:depth=5``
+                    #    restricts the search depth to 5).
+                    #
+                    #    The both types of expressions could be mixed in one pattern.
+                    #    The full-name expression must be the last in the pattern and
+                    #    is applied to the remaining part of the name. For example
+                    #    ``:^stage_:?^det.*val$:depth=4`` selects the device ``stage_sim``
+                    #    and all its subdevices starting with ``det`` and ending with ``val``
+                    #    up to the total depth of 5 (depth=4 is set for the full-name expression).
+                    #    Note, that searching devices using full-name expressions is less
+                    #    efficient and should be minimized or avoided if possible.
+                    #
+                    #    Regular expressions may be preceded with one the keywords that
+                    #    defines the type of matching devices: ``__READABLE__``,
+                    #    ``__MOTOR__``, ``__DETECTOR__`` and ``__FLYABLE__``.
+                    #    For example, ``__READABLE__:^stage_:?^det.*val$:depth=4``
+                    #    selects only the devices that are readable.
                     "devices": {
-                        "DeviceType1": ("det1", "det2", "det3"),
+                        "DeviceType1": ("det1", ":^det2$", ":^det:val$", ":?^det.*val$"),
+                        "DeviceType2": ("__MOTOR__:?.*:depth=5"),
                     },
                     # Set default value to string 'det1'. The default value MUST be
                     #   defined in the function header for the parameter that has
@@ -161,6 +204,33 @@ def parameter_annotation_decorator(annotation):
                     "default": "'det1'",
                 },
 
+                # Parameter that accepts a plan or a list of plans
+                #   (plans must exist in RE Worker namespace,
+                #    reference to the plans will be passed to the plan).
+                "plans_to_run": {
+                    # Text descriptions of parameters are optional.
+                    "description": "Parameter that accepts a plan or a list of plans.",
+                    "annotation": "typing.Union[PlanType1, typing.List[PlanType2]]",
+
+                    # Similarly to lists of name patterns for devices, the lists of
+                    #   patterns for plan may include device names and name patterns
+                    #   based on regular expressions. The patterns always start with
+                    #   ``:`` and may contain only a single regular expressions.
+                    #   The regular expression may be preced with ``+``, ``-`` and ``?``
+                    #   characters (e.g. ``:?^count$), but those characters are ignored
+                    #   by the processing algorithm. ``depth`` can not be used in
+                    #   the plan patterns.
+                    #
+                    # In the following example, two lists of plan names are defined.
+                    #   Names of the plan lists are used as types in 'annotation'.
+                    #   The example of annotation above allows to pass one plan from
+                    #   the group 'PlanType1' or a list of plans from 'PlanType2'.
+                    "plans": {
+                        "PlanType1": (":^count$", "scan", "gridscan"),
+                        "PlanType2": ("more", "plan", "names", ":^move_"),
+                    },
+                },
+
                 "dwell_time": {
                     "description": "Dwell time.",
                     # The simple type 'float' should probably be specified as
@@ -213,7 +283,7 @@ def parameter_annotation_decorator(annotation):
             return isinstance(instance, (list, tuple))
 
         type_checker = jsonschema.Draft3Validator.TYPE_CHECKER.redefine("array", is_array)
-        ValidatorCustom = jsonschema.validators.extend(jsonschema.Draft3Validator, type_checker=type_checker)
+        ValidatorCustom = jsonschema.validators.extend(jsonschema.Draft7Validator, type_checker=type_checker)
         validator = ValidatorCustom(schema=_parameter_annotation_schema)
 
         # Validate annotation
