@@ -1210,7 +1210,9 @@ class PlanQueueOperations:
                     # This is one case when we need to insert the plan after the 'destination' plan.
                     before = False
                 else:
-                    before = src_index > pos_dest
+                    si = src_index if src_index >= 0 else queue_size + src_index
+                    pi = pos_dest if pos_dest >= 0 else queue_size + pos_dest
+                    before = si > pi
 
         except Exception as ex:
             raise IndexError(f"Destination plan ({dest_txt}) was not found: {str(ex)}.")
@@ -1589,9 +1591,9 @@ class PlanQueueOperations:
             if not immediate_execution:
                 # Pop plan from the front of the queue (it is the same plan as currently loaded)
                 await self._r_pool.lpop(self._name_plan_queue)
-                self._plan_queue_uid = self.new_item_uid()
 
             await self._set_running_item_info(plan)
+            self._plan_queue_uid = self.new_item_uid()
 
         except RuntimeError:
             raise
@@ -1660,6 +1662,7 @@ class PlanQueueOperations:
             await self._clear_running_item_info()
             if not loop_mode and not immediate_execution:
                 self._uid_dict_remove(item["item_uid"])
+            self._plan_queue_uid = self.new_item_uid()
             await self._add_to_history(item_cleaned)
         else:
             item_cleaned = {}
@@ -1709,6 +1712,7 @@ class PlanQueueOperations:
                 item_pushed_to_queue = self.set_new_item_uuid(item_cleaned)
                 self._uid_dict_remove(item["item_uid"])
                 await self._add_item_to_queue(item_pushed_to_queue, pos="front", filter_parameters=False)
+            self._plan_queue_uid = self.new_item_uid()
         else:
             item_cleaned = {}
         return item_cleaned
