@@ -10,6 +10,7 @@ from .manager import RunEngineManager
 from .comms import PipeJsonRpcReceive, validate_zmq_key
 from .profile_ops import get_default_startup_dir
 from .output_streaming import PublishConsoleOutput, setup_console_output_redirection
+from .logging_setup import setup_loggers
 
 from .. import __version__
 
@@ -40,6 +41,9 @@ class WatchdogProcess:
         self._re_manager = None
         self._re_worker = None
 
+        # The number of restarts of the manager processes including the first start.
+        self._re_manager_n_restarts = 0
+
         # Create pipes used for connections of the modules
         self._manager_conn = None  # Worker -> Manager
         self._worker_conn = None  # Manager -> Worker
@@ -71,7 +75,7 @@ class WatchdogProcess:
     # ======================================================================
     #             Handlers for messages from RE Manager
 
-    def _start_re_worker_handler(self):
+    def _start_re_worker_handler(self, user_group_permissions):
         """
         Creates worker process. This is a quick operation, because it starts RE Worker
         process without waiting for initialization.
@@ -84,6 +88,7 @@ class WatchdogProcess:
                 config=self._config_worker,
                 msg_queue=self._msg_queue,
                 log_level=self._log_level,
+                user_group_permissions=user_group_permissions,
             )
             self._re_worker.start()
             success, err_msg = True, ""
@@ -142,6 +147,7 @@ class WatchdogProcess:
     # ======================================================================
 
     def _start_re_manager(self):
+        self._re_manager_n_restarts += 1
         self._init_watchdog_state()
         self._re_manager = self._cls_run_engine_manager(
             conn_watchdog=self._manager_to_watchdog_conn,
@@ -150,13 +156,14 @@ class WatchdogProcess:
             name="RE Manager Process",
             msg_queue=self._msg_queue,
             log_level=self._log_level,
+            number_of_restarts=self._re_manager_n_restarts,
         )
         self._re_manager.start()
 
     def run(self):
 
         logging.basicConfig(level=max(logging.WARNING, self._log_level))
-        logging.getLogger(__name__).setLevel(self._log_level)
+        setup_loggers(log_level=self._log_level)
 
         # Requests
         self._comm_to_manager.add_method(self._start_re_worker_handler, "start_re_worker")
@@ -268,6 +275,20 @@ def start_manager():
         "If the path is directory, then the default file name "
         "'existing_plans_and_devices.yaml' is used.",
     )
+
+    parser.add_argument(
+        "--update-existing-plans-devices",
+        dest="update_existing_plans_devices",
+        type=str,
+        choices=["NEVER", "ENVIRONMENT_OPEN", "ALWAYS"],
+        default="ENVIRONMENT_OPEN",
+        help="Select when the list of existing plans and devices stored on disk should be "
+        "updated. The available choices are not to update the stored lists (NEVER), update "
+        "the lists when the environment is opened (ENVIRONMENT_OPEN) or update the lists each "
+        "the lists are changed (ALWAYS) "
+        "(default: %(default)s)",
+    )
+
     parser.add_argument(
         "--user-group-permissions",
         dest="user_group_permissions_path",
@@ -278,6 +299,21 @@ def start_manager():
         "'user_group_permissions.yaml' is used.",
     )
 
+    parser.add_argument(
+        "--user-group-permissions-reload",
+        dest="user_group_permissions_reload",
+        type=str,
+        choices=["NEVER", "ON_REQUEST", "ON_STARTUP"],
+        default="ON_STARTUP",
+        help="Select when user group permissions are reloaded from disk. Options: 'NEVER' - "
+        "RE Manager never attempts to load permissions from disk file. If permissions fail to load "
+        "from Redis, they are loaded from disk at the first startup of RE Manager or on request. "
+        "'ON_REQUEST' - permissions are loaded from disk file when requested by 'permission_reload' API call. "
+        "'ON_STARTUP' - permissions are loaded from disk each time RE Manager is started or when "
+        "'permission_reload' API request is received "
+        "(default: %(default)s)",
+    )
+
     parser.add_argument(
         "--redis-addr",
         dest="redis_addr",
@@ -413,7 +449,7 @@ def start_manager():
     setup_console_output_redirection(msg_queue)
 
     logging.basicConfig(level=max(logging.WARNING, log_level))
-    logging.getLogger("bluesky_queueserver").setLevel(log_level)
+    setup_loggers(log_level=log_level)
 
     stream_publisher = PublishConsoleOutput(
         msg_queue=msg_queue,
@@ -521,13 +557,22 @@ def start_manager():
             existing_pd_path = os.path.join(existing_pd_path, default_existing_pd_fln)
     else:
         existing_pd_path = os.path.join(startup_dir, default_existing_pd_fln)
-    if not os.path.isfile(existing_pd_path):
+    # The file may not exist, but the directory MUST exist
+    pd_dir = os.path.dirname(existing_pd_path) or "."
+    if not os.path.isdir(os.path.dirname(existing_pd_path)):
         logger.error(
-            "The list of allowed plans and devices was not found at "
-            "'%s'. Proceed without the list: all plans and devices will be accepted by RE Manager.",
+            "The directory for list of plans and devices ('%s')does not exist. "
+            "Create the directory manually and restart RE Manager.",
+            pd_dir,
+        )
+        return 1
+    if not os.path.isfile(existing_pd_path):
+        logger.warning(
+            "The file with the list of allowed plans and devices ('%s') does not exist. "
+            "The manager will be started with empty list. The list will be populated after "
+            "RE worker environment is opened the first time.",
             existing_pd_path,
         )
-        existing_pd_path = None
 
     default_user_group_pd_fln = "user_group_permissions.yaml"
     if args.user_group_permissions_path:
@@ -541,16 +586,20 @@ def start_manager():
     if not os.path.isfile(user_group_pd_path):
         logger.error(
             "The file with user permissions was not found at "
-            "'%s'. User groups are not defined. USERS WILL NOT BE ABLE TO SUBMIT PLANS.",
+            "'%s'. User groups are not defined. USERS WILL NOT BE ABLE TO SUBMIT PLANS OR "
+            "EXECUTE ANY OTHER OPERATIONS THAT REQUIRE PERMISSIONS.",
             user_group_pd_path,
         )
         user_group_pd_path = None
 
     config_worker["existing_plans_and_devices_path"] = existing_pd_path
     config_manager["existing_plans_and_devices_path"] = existing_pd_path
-    config_worker["user_group_permissions_path"] = user_group_pd_path
     config_manager["user_group_permissions_path"] = user_group_pd_path
 
+    config_worker["update_existing_plans_devices"] = args.update_existing_plans_devices
+
+    config_manager["user_group_permissions_reload"] = args.user_group_permissions_reload
+
     # Read private key from the environment variable, then check if the CLI parameter exists
     zmq_private_key = os.environ.get("QSERVER_ZMQ_PRIVATE_KEY", None)
     zmq_private_key = zmq_private_key if zmq_private_key else None  # Case of key==""
