@@ -1144,6 +1144,18 @@ def test_replace_item_4_failing():
     ({"pos": 4, "pos_dest": 0}, 4, "eabcd", True, True, ""),
     ({"pos": 3, "pos_dest": "front"}, 3, "dabce", True, True, ""),
     ({"pos": 2, "pos_dest": "back"}, 2, "abdec", True, True, ""),
+    ({"pos": -1, "pos_dest": 0}, 4, "eabcd", True, True, ""),
+    ({"pos": -1, "pos_dest": 1}, 4, "aebcd", True, True, ""),
+    ({"pos": -2, "pos_dest": 0}, 3, "dabce", True, True, ""),
+    ({"pos": -2, "pos_dest": 1}, 3, "adbce", True, True, ""),
+    ({"pos": -1, "pos_dest": -5}, 4, "eabcd", True, True, ""),
+    ({"pos": -1, "pos_dest": -4}, 4, "aebcd", True, True, ""),
+    ({"pos": -2, "pos_dest": -5}, 3, "dabce", True, True, ""),
+    ({"pos": -2, "pos_dest": -4}, 3, "adbce", True, True, ""),
+    ({"pos": -2, "pos_dest": -3}, 3, "abdce", True, True, ""),
+    ({"pos": -4, "pos_dest": -2}, 1, "acdbe", True, True, ""),
+    ({"pos": -3, "pos_dest": -2}, 2, "abdce", True, True, ""),
+    ({"pos": -2, "pos_dest": -2}, 3, "abcde", True, False, ""),
     ({"uid": "p3", "after_uid": "p3"}, 2, "abcde", True, False, ""),
     ({"uid": "p1", "before_uid": "p2"}, 0, "abcde", True, True, ""),
     ({"uid": "p1", "after_uid": "p2"}, 0, "bacde", True, True, ""),
@@ -1260,6 +1272,16 @@ def test_move_item_2():
     ({"after_uid": "6"}, "0123456", "23", "23", "0145623", True, ""),
     ({"before_uid": "5"}, "0123456", "23", "23", "0142356", True, ""),
     ({"after_uid": "5"}, "0123456", "23", "23", "0145236", True, ""),
+
+    ({"pos_dest": 0}, "0123456", "23", "23", "2301456", True, ""),
+    ({"pos_dest": -7}, "0123456", "23", "23", "2301456", True, ""),
+    ({"pos_dest": 1}, "0123456", "23", "23", "0231456", True, ""),
+    ({"pos_dest": -6}, "0123456", "23", "23", "0231456", True, ""),
+    ({"pos_dest": 5}, "0123456", "23", "23", "0145236", True, ""),
+    ({"pos_dest": -2}, "0123456", "23", "23", "0145236", True, ""),
+    ({"pos_dest": 6}, "0123456", "23", "23", "0145623", True, ""),
+    ({"pos_dest": -1}, "0123456", "23", "23", "0145623", True, ""),
+
     # Controlling the order of moved items
     ({"after_uid": "5"}, "0123456", "023", "023", "1450236", True, ""),
     ({"after_uid": "5"}, "0123456", "203", "203", "1452036", True, ""),
@@ -1628,15 +1650,15 @@ def test_process_next_item_1(func, loop_mode, immediate_execution):
             else:
                 assert False, f"Unknown test case: '{func}'"
 
-            pq_uid = pq.plan_queue_uid
-            queue_1 = await pq.get_queue()
+            pq_uid1 = pq.plan_queue_uid
+            queue_1, _ = await pq.get_queue()
 
             # If the next plan is set as running, it is removed from the queue and
             #   the queue UID is changed. If a plan is set for immediate execution,
             #   then the queue and the queue UID remain unchanged.
             params = {"item": plan4} if immediate_execution else {}
             running_plan = await f(**params)
-            queue_2 = await pq.get_queue()
+            queue_2, _ = await pq.get_queue()
 
             assert running_plan != {}
 
@@ -1644,20 +1666,20 @@ def test_process_next_item_1(func, loop_mode, immediate_execution):
                 assert running_plan["name"] == "d"
                 assert "properties" in running_plan
                 assert running_plan["properties"]["immediate_execution"] is True
-                assert pq.plan_queue_uid == pq_uid
+                assert pq.plan_queue_uid != pq_uid1
                 assert await pq.get_queue_size() == 3
                 assert len(pq._uid_dict) == 3
                 assert queue_1 == queue_2
             else:
                 assert running_plan["name"] == "a"
-                assert pq.plan_queue_uid != pq_uid
+                assert pq.plan_queue_uid != pq_uid1
                 assert await pq.get_queue_size() == 2
                 assert len(pq._uid_dict) == 3
 
             # Apply if a plan is already running
-            pq_uid = pq.plan_queue_uid
+            pq_uid1 = pq.plan_queue_uid
             assert await f() == {}
-            assert pq.plan_queue_uid == pq_uid
+            assert pq.plan_queue_uid == pq_uid1
             assert await pq.get_queue_size() == (3 if immediate_execution else 2)
             assert len(pq._uid_dict) == 3
 
@@ -2065,7 +2087,8 @@ def test_set_processed_item_as_stopped_2(loop_mode, func):
 
             await pq.process_next_item(item=plan4)
 
-            assert pq.plan_queue_uid == pq_uid
+            assert pq.plan_queue_uid != pq_uid
+            pq_uid2 = pq.plan_queue_uid
             assert pq.plan_history_uid == ph_uid
 
             if func == "completed":
@@ -2080,7 +2103,7 @@ def test_set_processed_item_as_stopped_2(loop_mode, func):
             assert queue_1 == queue_2
             assert await pq.get_queue_size() == 3
             assert await pq.get_history_size() == 1
-            assert pq.plan_queue_uid == pq_uid
+            assert pq.plan_queue_uid != pq_uid2
             assert pq.plan_history_uid != ph_uid
 
             def check_plan(p):
